@@ -2,8 +2,12 @@
 #' @aliases discoveR
 #' @docType package
 #' @title Exploratory Data Analysis System
-#' @author Oldemar Rodriguez Rojas \cr
-#' Maintainer: Oldemar Rodriguez Rojas <oldemar.rodriguez@ucr.ac.cr>
+#' @author
+#' Maintainer: Oldemar Rodriguez Rojas <oldemar.rodriguez@ucr.ac.cr>\cr
+#' \itemize{
+#'   \item Oldemar Rodriguez Rojas <oldemar.rodriguez@ucr.ac.cr>
+#'   \item Diego Jiménez Alvarado
+#' }
 #' @description
 #' Performs an exploratory data analysis through a 'shiny' interface. 
 #' It includes basic methods such as the mean, median, mode, normality test, 
@@ -13,8 +17,8 @@
 #' \tabular{ll}{
 #' Package: \tab discoveR\cr
 #' Type: \tab Package\cr
-#' Version: \tab 2.2.6\cr
-#' Date: \tab 2021-10-08\cr
+#' Version: \tab 3.1.2\cr
+#' Date: \tab 2023-01-18\cr
 #' License: \tab GPL (>=2)\cr
 #' }
 #' @keywords package
@@ -23,5 +27,6 @@
 NULL
 utils::globalVariables(c(
   "tab.disjonctif", "cant", "x", "y", "xend", "yend", "grupo", "Dim.1", "<<-",
-  "Dim.2", "cj_colors", "cluster", "id", "k_colors", "n", "name", "value", "z"
+  "Dim.2", "cj_colors", "cluster", "id", "k_colors", "n", "name", "value", "z",
+  "colorRow", "etq"
 ))
